package ctbrec.io;

import java.time.Duration;
import java.time.Instant;
import java.util.ConcurrentModificationException;
import java.util.HashMap;
import java.util.Map;
import java.util.Map.Entry;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import ctbrec.Model;
import ctbrec.UnknownModel;

public class MissedSegmentsStatistics {

    private static final Logger LOG = LoggerFactory.getLogger(MissedSegmentsStatistics.class);

    private static Map<Model, Short> missegSegmentsCount = new HashMap<>();
    private static Instant lastOutput = Instant.EPOCH;
    private static Instant lastclear = Instant.now();
    private static Thread t;
    static {
        increase(new UnknownModel(), (short) 0);
    }

    private MissedSegmentsStatistics() {}

    public static void increase(Model model, short amount) {
        if (Duration.between(lastclear, Instant.now()).toHours() > 24) {
            missegSegmentsCount.clear();
            LOG.debug("Missed segments statistics cleared");
        }
        short total = missegSegmentsCount.getOrDefault(model, (short) 0);
        missegSegmentsCount.put(model, (short) (total + amount));
        if (t == null) {
            t = new Thread(() -> {
                while (true) {
                    printStatistics();
                    try {
                        Thread.sleep(1000);
                    } catch (InterruptedException e) {
                        Thread.currentThread().interrupt();
                        e.printStackTrace();
                    }
                }
            });
            t.setName("MissingSegments logger");
            t.setPriority(Thread.MIN_PRIORITY);
            t.setDaemon(true);
            t.start();
        }
    }

    private static void printStatistics() {
        Instant now = Instant.now();
        StringBuilder sb = new StringBuilder("Missed segments stats:\n");
        if (Duration.between(lastOutput, now).getSeconds() > 120) {
            try {
                for (Entry<Model, Short> entry : missegSegmentsCount.entrySet()) {
                    sb.append('\t').append(entry.getKey().getName()).append(": ").append(entry.getValue()).append('\n');
                }
                LOG.debug(sb.toString());
                lastOutput = now;
            } catch(ConcurrentModificationException e) {
                // ignore
            }
        }
    }
}
